.help.ESS <-
function (topic, package = NULL, lib.loc = NULL, verbose = getOption("verbose"), 
    try.all.packages = getOption("help.try.all.packages"), help_type = getOption("help_type")) 
{
    types <- c("text", "html", "pdf")
    if (!missing(package)) 
        if (is.name(y <- substitute(package))) 
            package <- as.character(y)
    if (missing(topic)) {
        if (!missing(package)) {
            help_type <- if (!length(help_type)) 
                "text"
            else match.arg(tolower(help_type), types)
            if (interactive() && help_type == "html") {
                if (tools:::httpdPort == 0L) 
                  tools::startDynamicHelp()
                if (tools:::httpdPort <= 0L) 
                  return(library(help = package, lib.loc = lib.loc, 
                    character.only = TRUE))
                browser <- if (.Platform$GUI == "AQUA") {
                  get("aqua.browser", envir = as.environment("tools:RGUI"))
                }
                else getOption("browser")
                browseURL(paste0("http://127.0.0.1:", tools:::httpdPort, 
                  "/library/", package, "/html/00Index.html"), 
                  browser)
                return(invisible())
            }
            else return(library(help = package, lib.loc = lib.loc, 
                character.only = TRUE))
        }
        if (!missing(lib.loc)) 
            return(library(lib.loc = lib.loc))
        topic <- "help"
        package <- "utils"
        lib.loc <- .Library
    }
    ischar <- tryCatch(is.character(topic) && length(topic) == 
        1L, error = identity)
    if (inherits(ischar, "error")) 
        ischar <- FALSE
    if (!ischar) {
        reserved <- c("TRUE", "FALSE", "NULL", "Inf", "NaN", 
            "NA", "NA_integer_", "NA_real_", "NA_complex_", "NA_character_")
        stopic <- deparse(substitute(topic))
        if (!is.name(substitute(topic)) && !stopic %in% reserved) 
            stop("'topic' should be a name, length-one character vector or reserved word")
        topic <- stopic
    }
    help_type <- if (!length(help_type)) 
        "text"
    else match.arg(tolower(help_type), types)
    paths <- index.search(topic, find.package(package, lib.loc, 
        verbose = verbose))
    tried_all_packages <- FALSE
    if (!length(paths) && is.logical(try.all.packages) && !is.na(try.all.packages) && 
        try.all.packages && missing(package) && missing(lib.loc)) {
        for (lib in .libPaths()) {
            packages <- .packages(TRUE, lib)
            packages <- packages[is.na(match(packages, .packages()))]
            paths <- c(paths, index.search(topic, file.path(lib, 
                packages)))
        }
        paths <- paths[paths != ""]
        tried_all_packages <- TRUE
    }
    paths <- unique(paths)
    attributes(paths) <- list(call = match.call(), topic = topic, 
        tried_all_packages = tried_all_packages, type = help_type)
    class(paths) <- "help_files_with_topic"
    paths
}
.Random.seed <-
c(403L, 52L, -1512485404L, -1201710358L, -2099419347L, -1648113357L, 
566110260L, 1780687208L, 995603922L, -1380447526L, -1423792238L, 
-1284267588L, 411650016L, -1427761276L, -187046142L, 2084467433L, 
239112778L, 1159132084L, 1483753579L, 2123726024L, 245541964L, 
-1116772070L, 1065898328L, 2064913678L, 2035182136L, 1381258732L, 
32079693L, 1009344283L, -402267595L, 882991227L, -866056274L, 
-514960898L, -1176391046L, -764905876L, 233086854L, 1206834958L, 
892246456L, 1983694759L, -1494132370L, -1417143358L, -198561454L, 
37106078L, 828807929L, 501501295L, 1648034227L, -797215157L, 
784639294L, -587101183L, 931878531L, 617769035L, -328673245L, 
-492714449L, 718329421L, -1027820187L, -15795609L, -1653831121L, 
-2012984883L, -1892491874L, -915454854L, 103323277L, 1997491980L, 
-416190375L, 1082453709L, -1368419886L, -699930426L, 1125807873L, 
227287177L, 634529127L, 738917031L, 2014597593L, 1327502088L, 
1556462759L, 1908445L, -920808260L, 1058813500L, -810239789L, 
-1462858322L, -1876472635L, 1699282638L, 1059016029L, -1674397590L, 
-778483433L, 5016548L, 65923111L, 125860466L, -1567448471L, -1491190061L, 
-1222038307L, 1688045479L, -1261518207L, 1203475100L, 1335559078L, 
668513978L, -481525211L, 2036908817L, 765906151L, 517247712L, 
1307614891L, -1024688827L, 4780942L, 147423368L, -1404145341L, 
-818037547L, 1137232478L, -2053434725L, -332213133L, 640727629L, 
-937843356L, -1509744404L, -648477807L, -579255395L, 1463939939L, 
-731771436L, -163172554L, -1386216634L, 1932070157L, -524238386L, 
1751867550L, -1847267853L, -1590049997L, 931420982L, 351682507L, 
1541852387L, 1189664991L, 1706378616L, -1042872020L, -731569905L, 
96161506L, -1062684021L, -970686792L, -1105914900L, 1183898820L, 
341344209L, -736735523L, -1398005025L, -534082000L, 398800308L, 
-1111639387L, -1830118474L, 690271059L, 424354099L, 1079417855L, 
-1886205692L, -2094453384L, 258704518L, -211641020L, 1214500275L, 
1517800151L, 319299795L, -1966274060L, 155394267L, -1673937494L, 
1527734652L, -516459887L, -1376965750L, 147000253L, 53237928L, 
-474765715L, 927872010L, 1055408813L, -907737949L, 1216166849L, 
889118942L, 999560125L, 1294591002L, 1229074828L, -715559281L, 
-1150214758L, -461767848L, 1900719512L, 1817543506L, 1961889247L, 
-119992897L, 479089849L, -1114184753L, 1469373599L, 842171608L, 
918095296L, 1650523199L, 1034835838L, 344495077L, -456267985L, 
-969651977L, -634334476L, -9035388L, 700165672L, 1383937178L, 
398627539L, 737077006L, -1998967515L, -521956292L, -1691338976L, 
-288045115L, -1669984269L, -1716941594L, -297063719L, -450550809L, 
493572135L, 856432479L, 1391021876L, -766022958L, 950825670L, 
865477737L, -362619028L, 1542181229L, 1092314229L, -84488954L, 
753596839L, 667540407L, -1120266142L, 2082547808L, 249411676L, 
-2083390513L, 331386245L, -1426242126L, -1476097107L, -1926248170L, 
-1139225409L, -1230574510L, -2111918627L, -80954719L, 558017514L, 
-690377153L, -1672905708L, -2076795694L, -329603418L, 1958342062L, 
68170872L, -437385224L, 804165980L, 1212726709L, -656560730L, 
-27072691L, -1292178285L, -170147341L, 893296957L, -2012888009L, 
-889920306L, -70012069L, 2038330991L, -1255817467L, -1040845668L, 
1252208254L, -967217362L, 1505523553L, 614931095L, 1129294462L, 
-462047147L, -2021209671L, -1630246237L, 626028375L, -559340436L, 
-738367723L, 1123987710L, 1619955138L, -1281779855L, -1273444303L, 
-876541719L, 1220607846L, -1466916440L, -72256957L, -842019740L, 
-1329178648L, 1849256843L, 560637512L, 1948683156L, 1069131768L, 
-1023901985L, -1145549254L, -276182827L, 352617347L, -1968331630L, 
2104076486L, 1268900373L, -1133340601L, -1411828304L, 1130524731L, 
-300607495L, 449943L, -680532583L, -1839985379L, -1509633985L, 
139266595L, 1307576481L, -628555904L, 1277607767L, 110422744L, 
-61373148L, -652734814L, 1428178120L, 888194673L, 1520099109L, 
1303694428L, 1108969548L, -122755696L, -1546571501L, -939547395L, 
1560984783L, -841574990L, 1631498628L, 737344661L, -1780753783L, 
-2129904317L, 428316170L, -1980059994L, -33072670L, 1882085634L, 
-973886955L, -1956652288L, 874489762L, 1580991109L, 940877799L, 
-1332033939L, -147634533L, -2129943313L, 1827367557L, 190529115L, 
-122862486L, 1826328468L, -1315812603L, 326729980L, -1604553816L, 
-2088631996L, 1682131279L, -1990301553L, -2066664589L, -1726463611L, 
36394110L, -2137854994L, 968359969L, -538696978L, 417188107L, 
768121102L, -618757754L, -1596061898L, -845987957L, 2039270833L, 
1685826142L, -341101294L, 1126621226L, 478740855L, -1215806330L, 
716997426L, -1513878748L, 1431016713L, -618829021L, -912054710L, 
291028223L, 1734035991L, 224875699L, 590545705L, -992233724L, 
1261965370L, 2062020223L, -1425533487L, 893161299L, -1097938871L, 
-7242179L, 1260895886L, -280695963L, 982009954L, -1561135800L, 
-2059624278L, 205951567L, -970860120L, -1767013076L, -1100662064L, 
1654026689L, -282393129L, 594755006L, -162477206L, 186048438L, 
1150214683L, -924921083L, 346510470L, -1154948907L, 149038407L, 
-976078763L, 550646300L, -1617402580L, -1332542226L, 1084187592L, 
258546117L, 752309484L, -1310264856L, 1397722044L, 1972622717L, 
917983915L, 493154546L, -413812168L, 1156384980L, -402949051L, 
-1218301429L, -1808532287L, 756169757L, -510276727L, -68699851L, 
-765661816L, 660835940L, -2022864308L, -1330582017L, -416420902L, 
-1699101642L, 1756664330L, 2114846806L, 1576211756L, -426031951L, 
875108105L, -1731314585L, -1936804285L, -1088490970L, 902994419L, 
-1580131230L, -575375902L, 2122569635L, 2050361327L, -2000267801L, 
-47222496L, 84655972L, 1132037661L, 904809516L, -1207536194L, 
744759259L, 1900100686L, -394124655L, 1723763614L, -1689742274L, 
-1317941267L, 28670497L, 1781511059L, 893405688L, 2114852054L, 
1495376581L, -339204465L, 981324388L, -1018720577L, 1603773024L, 
-524071972L, -1167017489L, 628846466L, -394580046L, -1160479840L, 
-228566537L, 1928887860L, 1632884974L, -765106532L, -1685038134L, 
-934346620L, -133298609L, 1701179543L, -509391166L, 1084471856L, 
-2020161439L, -382091529L, 1807902371L, -1488071018L, 184641866L, 
1865581612L, -352518817L, 474701106L, 2024994053L, 1871416656L, 
-221821288L, -981312704L, -1144938952L, 1014624493L, 1930959419L, 
-1240565131L, -380941068L, 87684L, -223612846L, 2039712242L, 
1140630523L, 77710830L, -447685470L, 1472689768L, 2146549100L, 
671780466L, 2027249444L, -1318589945L, -715006149L, -739839474L, 
1021132601L, 428176787L, -1627324224L, -1737376864L, -1447865823L, 
-1440050308L, 120454162L, 483950428L, -811243205L, 1884252514L, 
907188280L, -991586397L, 1587950896L, -403856529L, -2076789192L, 
498455383L, 2031790205L, -683306736L, -735812575L, -1440386046L, 
1106317423L, 1417364297L, -1643581012L, 538270237L, -260593162L, 
-479874581L, -2057149621L, 1970246194L, 1325441021L, -1069707988L, 
925568329L, -34084936L, -993224441L, 1994636834L, -214108485L, 
1030861098L, -1513934931L, 969536397L, 721089750L, 534221655L, 
1930055976L, -149498459L, -1538256723L, -929809011L, 675855112L, 
727915207L, 119999841L, -995318776L, 761553515L, 1703673868L, 
530318331L, -1716095004L, 704799804L, 1875839278L, -335530586L, 
160942553L, -1872373357L, -682162780L, -1053707283L, -494558978L, 
-715197086L, 382663392L, 764786533L, -348735494L, -707333900L, 
-544118387L, 1491527551L, 1129989165L, 132008965L, 2032820676L, 
-679251668L, -432801948L, -900619685L, -887959829L, 1985173975L, 
-389725944L, 1768603473L, -1093547306L, 1979725685L, -1061957876L, 
-1446340758L, -742377627L, 1907198514L, 1097029991L, -1303439723L, 
-476796770L, 289497377L, -824242148L, -1059962188L, -855943561L, 
2030390625L, 2136735822L, 1641911396L, -168023471L, -308493541L, 
-1467557154L, -404847204L, -1755693779L, -247520908L, 1346322168L, 
1948178296L, -592672803L, 495831805L, -579807244L, 1601833141L, 
-1491829622L, 456934028L, -955097789L, 1126844208L, -1969880696L, 
-559142481L, 1888970744L, 788907650L, -337537480L, -1009467176L, 
1222269714L, -1328318351L, -1286383379L, -63982241L, 1298498133L, 
1904870352L, 563354976L, 1587967014L, 805939414L, -910601474L, 
1775749501L, -800345956L, -22799655L, 1541685703L, 1273309523L, 
-1931224848L, -1087806923L, -458533428L, -153151517L, 1375670237L, 
-1275967556L, -1709650118L, -957871401L, -587075083L, 1237048725L, 
2122242667L, 1459320022L, -1434076963L, 1972316310L)
