\name{mbzinb.results}
\alias{mbzinb.results}
\title{
Likelihood ratio test results table
}
\description{
Outputs a table of results from an \code{mbzinb} analysis.
}
\usage{
mbzinb.results(mbzinb.list, sort.by.pvalue = TRUE, nreturn = 20, 
  baseline.group = NULL, p.adj.method = "fdr", include.taxonomy = FALSE)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{mbzinb.list}{
  An object of class \code{mbzinb} on which an analysis has been performed using \code{test.mbzinb}
}
  \item{sort.by.pvalue}{
  Should the results table be sorted such that the results with the lowest p-value are at the top?  Default is \code{TRUE}
}
  \item{nreturn}{
  How many taxa should results be returned on?  Default is 20.
}
  \item{baseline.group}{
  Name of the baseline group.  Should be a level of the grouping variable used in the analysis.  See details.  
}
  \item{p.adj.method}{
  Method to adjust p-values for multiple testing.  Default is \code{"fdr"}.  See the documentation for \code{stats:p.adjust} for other possibilities.
}
  \item{include.taxonomy}{
  If this is set to \code{TRUE}, the corresponding taxonomy table rows will be included in the results table.  If set to \code{TRUE}, \code{mbzinb.list} should include a taxonomy table.
}
}
\details{
Model fit to the data is a zero-inflated negative binomial model.  The prevalence is 1- the excess zero probability.  The mean is a normalization factor m times an abundance parameter a.  Let mu=m*a and let the dispersion parameter be r.  The variance is mu+mu^2*r.

The baseline group has its coefficients output and is the denominator in log-fold-change estimates.  If this argument is not supplied, it will be the first level of the variable when it is converted to a factor.

NA values will result when a fit did not converge or in some boundary conditions.  For example, if one group has all zero counts, there is no unique maximum likelihood estimate, so its parameter estimates will be \code{NA}.
}
\value{
Returns a data frame with some or all of:

\item{base.mean}{fitted mean abundance parameter times the fitted prevalence in baseline group}
\item{mean.LFC}{log2-fold change in fitted mean between other group and baseline}
\item{base.abund}{fitted mean abundance parameter in baseline group}
\item{abund.LFC}{log2-fold change in fitted mean abundance parameter between other group and baseline}
\item{base.prev}{fitted prevalence in baseline group}
\item{prev.change}{(linear) difference in prevalence between baseline group and other group (other-baseline)}
\item{base.disp}{fitted dispersion parameter in baseline group}
\item{disp.LFC}{log2-fold change in fitted dispersion parameter between other group and baseline}
\item{statistic}{value of likelihood ratio test statistic}
\item{PValue}{likelihood ratio test p-value, unadjusted}
\item{Padj}{p-value adjusted for multiple comparisons according to the method in \code{p.adj.method}}

Depending on the full model fit, not all columns will be available and the column names can differ.  For example, the test for differential mean and prevalence only does not include the dispersion log-fold-change, and \code{base.disp} is changed to \code{disp}.
}
\references{
%% ~put references to the literature/web site here ~
}
\author{
Emily King
}
\note{
%%  ~~further notes~~
}

%% ~Make other sections like Warning with \section{Warning }{....} ~

\seealso{
%% ~~objects to See Also as \code{\link{help}}, ~~~
}
\examples{
data(IBDdat)
LR.test <- mbzinb.test(IBDdat, group="ULCERATIVE_COLIT_OR_CROHNS_DIS")
mbzinb.results(LR.test, baseline.group="Healthy", include.taxonomy=TRUE)
}
% Add one or more standard keywords, see file 'KEYWORDS' in the
% R documentation directory.
\keyword{results summary}
