\name{mbzinb.test}
\alias{mbzinb.test}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{
Likelihood ratio tests for between-group differences
}
\description{
Perform likelihood ratio tests for between-group differences on an object of class mbzinb.
}
\usage{
mbzinb.test(mbzinb.data, group, filter.if.unfiltered = TRUE, LRT = "omnibus", 
  outlier.option = "winsor", upper.p = 0.97, cooks.cutoff = 1, use.zeroinfl = FALSE)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{mbzinb.data}{
  An object of class \code{mbzinb}.  
}
  \item{group}{
  group should be a column name or number in \code{mbzinb.data$sample}.  This will be used as a grouping variable in the analysis
}
  \item{filter.if.unfiltered}{
  Should the data be filtered (with default settings) if it has not been filtered already using \code{filter.dataset}?  Default is \code{TRUE}.  See \code{filter.dataset} for default settings.
}
  \item{LRT}{
  Which likelihood ratio test should be used?  Default is \code{"omnibus"}.
}
  \item{outlier.option}{
  Microbiome count data frequently has outliers which can elevate Type I Error.  \code{"winsor"} (default) and \code{"cooks"} both identify and replace potential outliers before analysis.  \code{"none"} does nothing to the data.
}
  \item{upper.p}{
  Only applicable if using \code{"winsor"} outlier option. The upper quantile at which observations will be winsorised.  Default is \code{0.97}.
}
  \item{cooks.cutoff}{
  Only applicable if using \code{"cooks"} outlier option.  Observations with Cook's D above \code{cooks.cutoff} will be flagged as outliers.
}
  \item{use.zeroinfl}{
  Most models can also be fit using the \code{zeroinfl} function from the \code{pscl} package.  Set this to \code{TRUE} if you would prefer to use this fitting method.  The full model for the \code{"mean.prev"} test must be fit using \code{zeroinfl}.
}
}
\details{
If \code{mbzinb} does not have normalization factors, they will be computed using the default RLE method prior to analysis.

Model fit to the data is a zero-inflated negative binomial model.  The prevalence is 1- the excess zero probability.  The mean is a normalization factor m times an abundance parameter a.  Let mu=m*a and let the dispersion parameter be r.  The variance is mu+mu^2*r.

Possible likelihood ratio tests are \code{"omnibus"}, \code{"mean.prev"}, and \code{"dispersion"}.  The reduced model is a single group fit of the zero-inflated negative binomial model for all three tests.  In the omnibus test full model, all parameters are allowed to differ between groups.  In the mean.prev full model, the mean abundance and prevalence parameters are allowed to differ between groups, but the dispersion is the same.  In the dispersion test, only the dispersion is allowed to differ between groups.

Possible outlier methods methods are \code{"winsor"}, \code{"cooks"}, or \code{"none"}.  \code{"winsor"} and \code{"cooks"} both identify and replace potential outliers before analysis.  \code{"none"} does nothing to the data.  \code{"winsor"} replaces normalized counts above the \code{upper.p} quantile with the \code{upper.p} quantile and rescales them.  Note that it is different from traditional winsorisation because it does not do the same for the lower quantile (zeros are not outliers under the zero-inflated model).  \code{"cooks"} fits a single zero-inflated negative binomial model to the full data for each taxon (without using group information).  It computes Cook's D for each sample in each taxon.  Observations with Cook's D greater than \code{cooks.cutoff} are flagged as outliers.  High outliers are replaced with the largest nonoutlier normalized count for that taxon, rescaled by the sample normalization factor.  This is inspired by \code{DESeq2} outlier replacement, but differs.
}
\value{
Returns the original list object with some additional attributes:

\item{replaced.counts}{counts with outliers replaced, only if option \code{"winsor"} or \code{"cooks"} is used}
\item{test}{list with the test, outlier option, and grouping variable}
\item{full.fit}{list with the full model fits for each taxon}
\item{red.fit}{list with the reduced model fits for each taxon}
\item{results}{list containing parameter estimates, p-values, and test-statistics}

}
\references{
An omnibus test for differential abundance analysis. To be submitted.
}
\author{
Emily King
}
\note{
%%  ~~further notes~~
}

%% ~Make other sections like Warning with \section{Warning }{....} ~

\seealso{
%% ~~objects to See Also as \code{\link{help}}, ~~~
}
\examples{
data(IBDdat)
#Perform omnibus likelihood ratio test using default
#normalization, filtering, and outlier treatment
mbzinb.test(IBDdat, group="ULCERATIVE_COLIT_OR_CROHNS_DIS")
#Perform likelihood ratio test for differences in mean
#and prevalence using Cook's D outlier replacement
mbzinb.test(IBDdat, group="ULCERATIVE_COLIT_OR_CROHNS_DIS", LRT="mean.prev", outlier.option="cooks")
}
% Add one or more standard keywords, see file 'KEYWORDS' in the
% R documentation directory.
\keyword{likelihood ratio test}% __ONLY ONE__ keyword per line
