\name{norm.factors}
\alias{norm.factors}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{
Compute normalization factors
}
\description{
Add normalization factors to an object of class \code{mbzinb}.
}
\usage{
norm.factors(mbzinb.data, method = "RLE", p = 0.75, norm.factors = NULL)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{mbzinb.data}{
  An object of class \code{mbzinb}.
}
  \item{method}{
  Normalization method.  Can be \code{"RLE"}, \code{"RLE2"}, or \code{"CSSp"}. See details.
}
  \item{p}{
  Only applicable to CSSp normalization.  CSSp will use the sum of nonzero counts up to the \code{p} quantile as a normalization factor.  Default is \code{0.75}.
}
  \item{norm.factors}{
  Can supply normalization factors as a vector of the same length as the number of rows in \code{mbzinb.data} using this argument.  Will override any other normalization factors.
}
}
\details{
RLE normalization is used in the \code{DESeq} package.  The original version of this method does not work on data such as microbiome data in which most or all genera and OTU will have zero counts in some individuals.  \code{"RLE"} normalization in this package excludes zero counts.  \code{"RLE2"} adds one to each count, then computes normalization factors.  The original count matrix is retained in subsequent analyses.  \code{"CSSp"} normalization uses the sum of counts up to the pth quantile of nonzero counts as a normalization factor.  Normalization factors are define such that the expected count for an individual is an abundance parameter a times the normalization factor m (mu=a*m),
}
\value{
Returns the original \code{mbzinb} with normalization factors in \code{normFactors}
}
\references{
RLE normalization factors (used in DESeq):
Anders, S., & Huber, W. (2010). Differential expression analysis for sequence count data. Genome Biol, 11(10), R106.
RLE normalization with pseudocounts (RLE2):
McMurdie, P. J., & Holmes, S. (2014). Waste not, want not: Why rarefying microbiome data is inadmissible. PLoS Computational Biology, 10(4), e1003531.
Quantile (CSSp) normalization:
Bullard, J. H., Purdom, E., Hansen, K. D., & Dudoit, S. (2010). Evaluation of statistical methods for normalization and differential expression in mRNA-Seq experiments. BMC Bioinformatics, 11(1), 94.
}
\author{
Emily King
}
\note{
%%  ~~further notes~~
}

%% ~Make other sections like Warning with \section{Warning }{....} ~

\seealso{
%% ~~objects to See Also as \code{\link{help}}, ~~~
}
\examples{
data(IBDdat)
#Recommended to filter dataset before computing normalization factors
IBD.filtered <- filter.dataset(IBDdat)

#Compute RLE normalization factor omitting zero counts in computation
IBD.RLE.norm <- norm.factors(IBD.filtered)
IBD.RLE.norm$normFactors

#Compute normalization factors using RLE normalization with pseudocounts
IBD.RLE2.norm <- norm.factors(IBD.filtered, method = "RLE2")
IBD.RLE2.norm$normFactors

#Compute normalization factors scaling by 0.7 quantile of nonzero counts
IBD.CSS.norm <- norm.factors(IBD.filtered, method="CSSp", p=0.7)
IBD.CSS.norm$normFactors

#Custom normalization example
#Example normalization factors to add to object
mynormFactors <- norm.factors(IBD.filtered, method="CSSp", p=0.7)$normFactors
#Use custom normalization factors
IBD.custom.norm <- norm.factors(IBD.filtered, norm.factors=mynormFactors)
}
% Add one or more standard keywords, see file 'KEYWORDS' in the
% R documentation directory.
\keyword{normalization}
